Crate qconnection

Modules

builder
events
handshake
path
prelude
space
state
termination
tls
tx

Structs

Components
Connection

Enums

GuaranteedFrame
The kind of frame which guaratend to be received by peer.
SpecificComponents

Type Aliases

ArcDcidCell
ArcLocalCids
ArcReliableFrameDeque
ArcRemoteCids
CidRegistry
Credit
DataJournal
For data space, reliable transmission of GuaranteedFrame (crypto frames, stream frames and reliable frames) is required.
DataStreams
FlowController
Handshake
HandshakeJournal
For handshake space, only reliable transmission of crypto frames is required.
InitialJournal
For initial space, only reliable transmission of crypto frames is required.
RawHandshake
RouterRegistry
StreamReader
StreamWriter