Modules
Structs
Enums
- Guaranteed
Frame - The kind of frame which guaratend to be received by peer.
- Specific
Components
Type Aliases
- ArcDcid
Cell - ArcLocal
Cids - ArcReliable
Frame Deque - ArcRemote
Cids - CidRegistry
- Credit
- Data
Journal - For data space, reliable transmission of
GuaranteedFrame(crypto frames, stream frames and reliable frames) is required. - Data
Streams - Flow
Controller - Handshake
- Handshake
Journal - For handshake space, only reliable transmission of crypto frames is required.
- Initial
Journal - For initial space, only reliable transmission of crypto frames is required.
- RawHandshake
- Router
Registry - Stream
Reader - Stream
Writer